summaryrefslogtreecommitdiffstats
path: root/cmake
diff options
context:
space:
mode:
authorxtkoba <69125751+xtkoba@users.noreply.github.com>2021-10-13 16:00:06 +0900
committerGitHub <noreply@github.com>2021-10-13 16:00:06 +0900
commit0d12bff1becdc78bbeacb61643eb9b722b6d394e (patch)
treebbfc3a1d5a152bf0567c4fbccabbed45917830a3 /cmake
parentcf8114b5628ccfcf51ac244da3d648e602b35a74 (diff)
downloadrspamd-0d12bff1becdc78bbeacb61643eb9b722b6d394e.tar.gz
rspamd-0d12bff1becdc78bbeacb61643eb9b722b6d394e.zip
Support i386 with optimizations
Diffstat (limited to 'cmake')
-rw-r--r--cmake/ArchDep.cmake6
1 files changed, 3 insertions, 3 deletions
diff --git a/cmake/ArchDep.cmake b/cmake/ArchDep.cmake
index 71f2422ca..8271709b6 100644
--- a/cmake/ArchDep.cmake
+++ b/cmake/ArchDep.cmake
@@ -16,8 +16,8 @@ SET(ASM_CODE "
")
ASM_OP(HAVE_DOLLARMACRO "dollar macro convention")
-# For now we support only x86_64 architecture with optimizations
-IF("${ARCH}" STREQUAL "x86_64")
+# For now we support only x86_64/i386 architecture with optimizations
+IF("${ARCH}" STREQUAL "x86_64" OR "${ARCH}" STREQUAL "i386")
IF(NOT HAVE_SLASHMACRO AND NOT HAVE_DOLLARMACRO)
MESSAGE(FATAL_ERROR "Your assembler cannot compile macros, please check your CMakeFiles/CMakeError.log")
ENDIF()
@@ -99,4 +99,4 @@ IF ("${ARCH}" STREQUAL "x86_64")
ELSEIF((CMAKE_C_COMPILER_ID MATCHES "MSVC"))
ADD_COMPILE_OPTIONS(/arch:SSE2)
ENDIF()
-ENDIF() \ No newline at end of file
+ENDIF()